==> utensor_cgen-0.4.2.tar.gz: utensor_cgen-0.4.2/utensor_cgen/frontend/__init__.py <==
import importlib
import os

from .base import Parser


class FrontendSelector(object):
  _parser_map = {}
  _setuped = False

  @classmethod
  def register(cls, target_exts):
    def _register(parser_cls):
      if not issubclass(parser_cls, Parser):
        raise TypeError('incorrect parser type for registration')
      for ext in target_exts:
        if ext in cls._parser_map:
          raise ValueError("duplicate file ext detected: %s" % ext)
        cls._parser_map[ext] = parser_cls
      return parser_cls

    return _register

  @classmethod
  def parse(cls, model_file, output_nodes, config=None):
    if config is None:
      config = {}
    _, ext = os.path.splitext(model_file)
    parser = cls.select_parser(ext)(config)
    return parser.parse(model_file, output_nodes)

  @classmethod
  def select_parser(cls, file_ext):
    cls._setup()
    parser_cls = cls._parser_map.get(file_ext, None)
    if parser_cls is None:
      raise RuntimeError("unknown model file ext found: %s" % file_ext)
    return parser_cls
  
  @classmethod
  def _setup(cls):
    """
    Find all .py files under `utensor_cgen.frontend` and import it
    to register all parsers
    """
    if cls._setuped:
      return
    root_dir = os.path.dirname(__file__)
    _, _, files = next(os.walk(root_dir))
    for file in files:
      fname, ext = os.path.splitext(file)
      if fname not in ['__init__', 'base'] and ext == ".py":
        mod_name = 'utensor_cgen.frontend.%s' % fname
        importlib.import_module(mod_name)
    cls._setuped = True

==> utensor_cgen-1.0.0.tar.gz: utensor_cgen-1.0.0/utensor_cgen/frontend/__init__.py <==
import importlib
import os

from .base import Parser


class FrontendSelector(object):
  _parser_map = {}
  _setuped = False

  @classmethod
  def register(cls, target_exts, overwrite=False):
    def _register(parser_cls):
      if not issubclass(parser_cls, Parser):
        raise TypeError('incorrect parser type for registration')
      for ext in target_exts:
        if not overwrite and ext in cls._parser_map:
          raise ValueError("duplicate file ext detected: %s" % ext)
        cls._parser_map[ext] = parser_cls
      return parser_cls

    return _register

  @classmethod
  def parse(cls, model_file, output_nodes=None, config=None, model_name=None):
    if config is None:
      config = {}
    _, ext = os.path.splitext(model_file)
    parser = cls.select_parser(ext)(config)
    return parser.parse(model_file, output_nodes, model_name=model_name)

  @classmethod
  def select_parser(cls, file_ext):
    cls._setup()
    parser_cls = cls._parser_map.get(file_ext, None)
    if parser_cls is None:
      raise RuntimeError("unknown model file extension: %s" % file_ext)
    return parser_cls
  
  @classmethod
  def _setup(cls):
    """
    Find all .py files under `utensor_cgen.frontend` and import it
    to register all parsers
    """
    if cls._setuped:
      return
    root_dir = os.path.dirname(__file__)
    _, _, files = next(os.walk(root_dir))
    for file in files:
      fname, ext = os.path.splitext(file)
      if fname not in ['__init__', 'base'] and ext == ".py":
        mod_name = 'utensor_cgen.frontend.%s' % fname
        importlib.import_module(mod_name)
    cls._setuped = True
